@@ -268,13 +268,17 @@ class AuthController():
         l.info("edit user")
         userid = self.userid
         user = self.user
+        selfediting = False
         if self.request.matched_route.name == 'ppss:user:editself':
             userid = self.request.session[Conf.sessionuser]['id']
             user = self.getUserById(userid)
-            #self.userid = userid
-            #self.user = user
+            submiturl = self.request.route_url('ppss:user:editself')
+            selfediting = True
+        else:
+            submiturl = self.request.route_url('ppss:user:edit',elementid=userid)
+
         l.debug("***{id} -> {user}".format(user=user,id=userid))
-        retdict = dict(self.retdict,**{'msg':"",'res':True,'userid':userid} )
+        retdict = dict(self.retdict,**{'msg':"",'res':True,'userid':userid,'submiturl':submiturl} )
         if not user:
             retdict['res'] = False
             retdict['msg'] = "user not found"
@@ -286,9 +290,9 @@ class AuthController():
         
         if logged_user.isSuperUser():
             editablegroups = PPSsgroup.all(self.request.dbsession)
-        if logged_user.hasPermission('edituser'):
+        if logged_user.hasPermission('edituser') or selfediting:
             editablegroups =  logged_user.groups
-
+        l.debug("editablegroups = {}".format(editablegroups))
 
         retdict.update({"user" : user, 'allgroups':editablegroups })
 
